==> ansela_0.8-1.tar.gz: ansela-0.8/src/opt/anselA/filters/display.py <==
# -*- coding: utf-8 -*-
#CPE 1704 TKS
"""
For Hiding and Moving.
"""
from filters.toolbox import *
from PyQt4 import QtCore as QtCore

#######################################
#   Display functions
#######################################

def DisplayWait_Enable(self, UpdateRealImage):
    if  (self.core.lockUpdating == False):
        if (UpdateRealImage == True):
            showUpdateLabel(self, True,  False)
        else:
            showUpdateLabel(self, True,  True)
        return True
    else:
        return False
        
def showUpdateLabel(self, show,  thumb):
    ShowApply(self, True)
    self.lockUpdating = show
    if (thumb == True):
        if (show == True):
            self.labWaitThumb.setGeometry(self.photo_Thumb.geometry())
        else:
            self.labWaitThumb.setGeometry(QtCore.QRect(0, 0, 0, 0))
    else:
        if (show == True):
            WaitOverlay(self,"Updating Photo...",  "Large images may take a few seconds to process.")
            FullScreenToggle(self,True)
        else:
            FullScreenToggle(self,False)
            WaitOverlayHide(self)
    self.repaint()

def DisplayWait_Disable(self, UpdateRealImage,  Image):
    if (UpdateRealImage == True):
        self.core.current.image=Image
        self.photo.setPixmap(pil2qpixmap(self.core.current.image))

    else:
        self.photo_Thumb.setPixmap(pil2qpixmap(Image))
        showUpdateLabel(self, False,  True)

def PhotTabs_Hide(self):
    self.tabPhoto.removeTab(0) #// removes the tab at the index 1 which is the second tab from left
    self.tabPhoto.removeTab(0)
    #self.tabPhoto.removeTab(1)
    
def PhotTabs_Show(self):
    #self.tabPhoto.insertTab(1, self.tabFullscreen, "<Name of TabX>");  # The tab is added back.
    self.tabPhoto.insertTab(0, self.tabUndo, "Undo") # The tab is added back.
    self.tabPhoto.insertTab(0, self.tabFullscreen, "Fullscreen")

def ToggleThumbWait(self,  Show):
        if Show:
            self.labWaitThumb.setGeometry(-30, -30, 380, 450)
        else:
            self.labWaitThumb.setGeometry(0, 0, 0, 0)
        self.labWaitThumb.repaint()

def ShowApply(self, Show,  First = False):
    if self.core.ApplyVisible <> Show:
        self.core.ApplyVisible = Show
        self.btnApplyUndo.setText(":"+str(self.core.undoCount))
        if Show:
            self.btnApply.setVisible(True)
        else:
            self.btnApply.setVisible(False)

        if (self.core.undoCount != 0):
            self.btnApplyUndo.setVisible(True)
        else:
            self.btnApplyUndo.setVisible(False)
#######################################
#   Pop Wait
#######################################

def WaitOverlay(self,  WaitText, WaitInfoText=""):
    self.labPopWaitInfo.setText(WaitInfoText)
    self.labPopWait.setText(WaitText)
    self.labPopWait.setVisible(True)
    self.FramePopupWait.setVisible(True)
    self.FramePopupWait.setGeometry(0, 0, 800, 480)
    self.btnPopWaitOk.setVisible(False)
    self.repaint()
    
def WaitOverlayOk(self,  WaitText, WaitInfoText=""):
    self.labPopWaitInfo.setText(WaitInfoText)
    self.FramePopupWait.setVisible(True)
    self.labPopWait.setText(WaitText)
    self.btnPopWaitOk.setVisible(True)
    self.repaint()

def WaitOverlayHide(self):
    self.FramePopupWait.setGeometry(0, 0, 0, 480)
    self.repaint()
    
def FullScreenToggle(self,  Show,  ForceTab=0):
    if (Show):
        #AnimateWidget(self, self.photo_Thumb, 0, 0, 800, 400, 10)
        self.tabPhoto.setCurrentIndex(ForceTab)
        self.framePhoto.setGeometry(QtCore.QRect(0, 0, 800, 480))    
        self.photo.repaint()
    else:
        self.framePhoto.setGeometry(QtCore.QRect(0, 0, 0, 0))
    self.tabPhoto.updateGeometry()
    self.tabStrip.repaint()
    self.repaint()


def AnimateWidget(self, widget, Final_X=0, Final_Y=0, Final_W=0, Final_H=0,  steps=0):
    if (steps != 0):
        Move_X=0
        Move_Y=0
        Move_W=0
        Move_H=0
        Start_X=widget.geometry().x()
        Start_Y=widget.geometry().y()
        Start_W=widget.geometry().width()
        Start_H=widget.geometry().height()
            
        if(Final_X!=0):
            Move_X=(Final_X-Start_X)/(steps-1)
        if(Final_Y!=0):
            Move_Y=(Final_Y-Start_Y)/(steps-1)
        if(Final_W!=0):
            Move_W=(Final_W-Start_W)/(steps-1)
        if(Final_H!=0):
            Move_H=(Final_H-Start_H)/(steps-1)
            
        for i in range(1, steps):
            widget.setGeometry(Start_X+(Move_X*i), Start_Y+(Move_Y*i), Start_W+(Move_W*i), Start_H+(Move_H*i))
            widget.repaint()
        widget.setGeometry(Start_X+(Move_X*i), Start_Y+(Move_Y*i), Start_W+(Move_W*i), Start_H+(Move_H*i))
        widget.repaint()
        
        
#        for n in range(1, 10):
#            self.photoListZoom.setGeometry(400-30*n,  125, 250, 140)
#            self.photoListZoom.repaint()
#        time.sleep(0.1)

==> ansela_0.9-0.tar.gz: ansela-0.9/src/opt/anselA/filters/display.py <==
# -*- coding: utf-8 -*-
#CPE 1704 TKS
"""
For Hiding and Moving.
"""
from filters.toolbox import *
from PyQt4 import QtCore as QtCore

#######################################
#   Display functions
#######################################

def DisplayWait_Enable(self, UpdateRealImage):
    if  (self.core.lockUpdating == False):
        if (UpdateRealImage == True):
            showUpdateLabel(self, True,  False)
        else:
            showUpdateLabel(self, True,  True)
        return True
    else:
        return False
        
def showUpdateLabel(self, show,  thumb):
    ShowApply(self, True)
    self.lockUpdating = show
    if (thumb == True):
        if (show == True):
            #self.labWaitThumb.setGeometry(self.photo_Thumb.geometry())
            self.labWaitThumb.setGeometry(QtCore.QRect(-480, -130, 1300, 771))
        else:
            self.labWaitThumb.setGeometry(QtCore.QRect(-480, -130, 0, 771))
    else:
        if (show == True):
            WaitOverlay(self,"Updating Photo...",  "Large images may take a few seconds to process.")
            FullScreenToggle(self,True)
        else:
            FullScreenToggle(self,False)
            WaitOverlayHide(self)
    self.repaint()

def DisplayWait_Disable(self, UpdateRealImage,  Image):
    if (UpdateRealImage == True):
        self.core.current.image=Image
        self.photo.setPixmap(pil2qpixmap(self.core.current.image))

    else:
        self.photo_Thumb.setPixmap(pil2qpixmap(Image))
        showUpdateLabel(self, False,  True)

def PhotTabs_Hide(self):
    self.tabPhoto.removeTab(0) #// removes the tab at the index 1 which is the second tab from left
    self.tabPhoto.removeTab(0)
    #self.tabPhoto.removeTab(1)
    
def PhotTabs_Show(self):
    #self.tabPhoto.insertTab(1, self.tabFullscreen, "<Name of TabX>");  # The tab is added back.
    self.tabPhoto.insertTab(0, self.tabUndo, "Undo") # The tab is added back.
    self.tabPhoto.insertTab(0, self.tabFullscreen, "Fullscreen")

def ToggleThumbWait(self,  Show):
        if Show:
            self.labWaitThumb.setGeometry(QtCore.QRect(-480, -130, 1300, 771))
        else:
            self.labWaitThumb.setGeometry(QtCore.QRect(-480, -130, 0, 771))
        self.labWaitThumb.repaint()

def ShowApply(self, Show,  First = False):
    if self.core.ApplyVisible <> Show:
        self.core.ApplyVisible = Show
        self.btnApplyUndo.setText(":"+str(self.core.undoCount))
        if Show:
            self.btnApply.setVisible(True)
        else:
            self.btnApply.setVisible(False)

        if (self.core.undoCount != 0):
            self.btnApplyUndo.setVisible(True)
        else:
            self.btnApplyUndo.setVisible(False)
#######################################
#   Pop Wait
#######################################

def WaitOverlay(self,  WaitText, WaitInfoText=""):
    self.labPopWaitInfo.setText(WaitInfoText)
    self.labPopWait.setText(WaitText)
    self.labPopWait.setVisible(True)
    self.FramePopupWait.setVisible(True)
    self.FramePopupWait.setGeometry(0, 0, 800, 480)
    self.btnPopWaitOk.setVisible(False)
    self.repaint()
    
def WaitOverlayOk(self,  WaitText, WaitInfoText=""):
    self.labPopWaitInfo.setText(WaitInfoText)
    self.FramePopupWait.setVisible(True)
    self.labPopWait.setText(WaitText)
    self.btnPopWaitOk.setVisible(True)
    self.repaint()

def WaitOverlayHide(self):
    self.FramePopupWait.setGeometry(0, 0, 0, 480)
    self.repaint()
    
def FullScreenToggle(self,  Show,  ForceTab=0):
    if (Show):
        #AnimateWidget(self, self.photo_Thumb, 0, 0, 800, 400, 10)
        self.tabPhoto.setCurrentIndex(ForceTab)
        self.framePhoto.setGeometry(QtCore.QRect(0, 0, 800, 480))    
        self.photo.repaint()
    else:
        self.framePhoto.setGeometry(QtCore.QRect(0, 0, 0, 0))
    self.tabPhoto.updateGeometry()
    self.tabStrip.repaint()
    self.repaint()


def AnimateWidget(self, widget, Final_X=0, Final_Y=0, Final_W=0, Final_H=0,  steps=0):
    if (steps != 0):
        Move_X=0
        Move_Y=0
        Move_W=0
        Move_H=0
        Start_X=widget.geometry().x()
        Start_Y=widget.geometry().y()
        Start_W=widget.geometry().width()
        Start_H=widget.geometry().height()
            
        if(Final_X!=0):
            Move_X=(Final_X-Start_X)/(steps-1)
        if(Final_Y!=0):
            Move_Y=(Final_Y-Start_Y)/(steps-1)
        if(Final_W!=0):
            Move_W=(Final_W-Start_W)/(steps-1)
        if(Final_H!=0):
            Move_H=(Final_H-Start_H)/(steps-1)
            
        for i in range(1, steps):
            widget.setGeometry(Start_X+(Move_X*i), Start_Y+(Move_Y*i), Start_W+(Move_W*i), Start_H+(Move_H*i))
            widget.repaint()
        widget.setGeometry(Start_X+(Move_X*i), Start_Y+(Move_Y*i), Start_W+(Move_W*i), Start_H+(Move_H*i))
        widget.repaint()
        
        
#        for n in range(1, 10):
#            self.photoListZoom.setGeometry(400-30*n,  125, 250, 140)
#            self.photoListZoom.repaint()
#        time.sleep(0.1)
